==> de4a-core-schemas-0.2.7-sources.jar: eu/de4a/iem/core/jaxb/de/ObjectFactory.java <==

package eu.de4a.iem.core.jaxb.de;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import eu.de4a.iem.core.jaxb.common.EventNotificationType;
import eu.de4a.iem.core.jaxb.common.RedirectUserType;
import eu.de4a.iem.core.jaxb.common.ResponseExtractMultiEvidenceType;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the eu.de4a.iem.core.jaxb.de package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.&lt;p&gt;This class was annotated by ph-jaxb22-plugin -Xph-annotate&lt;/p&gt;
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _RequestForwardEvidence_QNAME = new QName("http://www.de4a.eu/2020/data/evaluator/v2", "RequestForwardEvidence");
    public final static QName _USIRedirectUser_QNAME = new QName("http://www.de4a.eu/2020/data/evaluator/v2", "USIRedirectUser");
    public final static QName _EventNotification_QNAME = new QName("http://www.de4a.eu/2020/data/evaluator/v2", "EventNotification");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: eu.de4a.iem.core.jaxb.de
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ResponseExtractMultiEvidenceType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ResponseExtractMultiEvidenceType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "http://www.de4a.eu/2020/data/evaluator/v2", name = "RequestForwardEvidence")
    @Nonnull
    public JAXBElement<ResponseExtractMultiEvidenceType> createRequestForwardEvidence(
        @Nullable
        final ResponseExtractMultiEvidenceType value) {
        return new JAXBElement<ResponseExtractMultiEvidenceType>(_RequestForwardEvidence_QNAME, ResponseExtractMultiEvidenceType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RedirectUserType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link RedirectUserType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "http://www.de4a.eu/2020/data/evaluator/v2", name = "USIRedirectUser")
    @Nonnull
    public JAXBElement<RedirectUserType> createUSIRedirectUser(
        @Nullable
        final RedirectUserType value) {
        return new JAXBElement<RedirectUserType>(_USIRedirectUser_QNAME, RedirectUserType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EventNotificationType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link EventNotificationType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "http://www.de4a.eu/2020/data/evaluator/v2", name = "EventNotification")
    @Nonnull
    public JAXBElement<EventNotificationType> createEventNotification(
        @Nullable
        final EventNotificationType value) {
        return new JAXBElement<EventNotificationType>(_EventNotification_QNAME, EventNotificationType.class, null, value);
    }

}

==> de4a-core-schemas-0.2.10-sources.jar: eu/de4a/iem/core/jaxb/de/ObjectFactory.java <==

package eu.de4a.iem.core.jaxb.de;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import eu.de4a.iem.core.jaxb.common.EventNotificationType;
import eu.de4a.iem.core.jaxb.common.RedirectUserType;
import eu.de4a.iem.core.jaxb.common.ResponseExtractMultiEvidenceType;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the eu.de4a.iem.core.jaxb.de package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.&lt;p&gt;This class was annotated by ph-jaxb22-plugin -Xph-annotate&lt;/p&gt;
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _ResponseTransferEvidence_QNAME = new QName("http://www.de4a.eu/2020/data/evaluator/v2", "ResponseTransferEvidence");
    public final static QName _USIRedirectUser_QNAME = new QName("http://www.de4a.eu/2020/data/evaluator/v2", "USIRedirectUser");
    public final static QName _EventNotification_QNAME = new QName("http://www.de4a.eu/2020/data/evaluator/v2", "EventNotification");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: eu.de4a.iem.core.jaxb.de
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ResponseExtractMultiEvidenceType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ResponseExtractMultiEvidenceType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "http://www.de4a.eu/2020/data/evaluator/v2", name = "ResponseTransferEvidence")
    @Nonnull
    public JAXBElement<ResponseExtractMultiEvidenceType> createResponseTransferEvidence(
        @Nullable
        final ResponseExtractMultiEvidenceType value) {
        return new JAXBElement<ResponseExtractMultiEvidenceType>(_ResponseTransferEvidence_QNAME, ResponseExtractMultiEvidenceType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RedirectUserType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link RedirectUserType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "http://www.de4a.eu/2020/data/evaluator/v2", name = "USIRedirectUser")
    @Nonnull
    public JAXBElement<RedirectUserType> createUSIRedirectUser(
        @Nullable
        final RedirectUserType value) {
        return new JAXBElement<RedirectUserType>(_USIRedirectUser_QNAME, RedirectUserType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EventNotificationType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link EventNotificationType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "http://www.de4a.eu/2020/data/evaluator/v2", name = "EventNotification")
    @Nonnull
    public JAXBElement<EventNotificationType> createEventNotification(
        @Nullable
        final EventNotificationType value) {
        return new JAXBElement<EventNotificationType>(_EventNotification_QNAME, EventNotificationType.class, null, value);
    }

}
